==> gnome-devel-docs-3.20.2-1-any.pkg.tar.xz: usr/share/help/C/gnome-devel-demos/samples/fontchooserwidget.js <==
//!/usr/bin/gjs

const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const FontChooserWidgetExample = new Lang.Class ({
    Name: 'Font Chooser Widget Example',

    // Create the application itthis
    _init: function () {
        this.application = new Gtk.Application({ application_id: 'org.example.fontchooserwidget' });

        // Connect 'activate' and 'startup' signals to the callback functions
        this.application.connect('activate', Lang.bind(this, this._onActivate));
        this.application.connect('startup', Lang.bind(this, this._onStartup));
    },

    // Callback function for 'activate' signal presents windows when active
    _onActivate: function() {
        this.window.present();
    },

    // Callback function for 'startup' signal builds the UI
    _onStartup: function() {
        this._buildUI ();
    },

    // Build the application's UI
    _buildUI: function() {
        // Create the application window
        this.window = new Gtk.ApplicationWindow  ({ application: this.application,
                                                    window_position: Gtk.WindowPosition.CENTER,
                                                    title: "FontChooserWidget",
                                                    default_width: 200,
                                                    default_height: 200,
                                                    border_width: 10 });

        this.fontChooser = new Gtk.FontChooserWidget();
        // a default font
        this.fontChooser.set_font("Sans");
        // a text to preview the font
        this.fontChooser.set_preview_text("This is an example of preview text!");

        // connect signal from the font chooser to the callback function
        this.fontChooser.connect("notify::font", Lang.bind(this, this._fontCb));

        // add the font chooser to the window
        this.window.add(this.fontChooser);
        this.window.show_all();
   },

     // callback function:
     _fontCb: function() {
        // print in the terminal
        print("You chose the font " + this.fontChooser.get_font());
    }
});

// Run the application
let app = new FontChooserWidgetExample();
app.application.run (ARGV);

==> gnome-devel-docs-3.32.1-1-any.pkg.tar.xz: usr/share/help/C/gnome-devel-demos/samples/fontchooserwidget.js <==
//!/usr/bin/gjs

imports.gi.versions.Gtk = '3.0';
const Gtk = imports.gi.Gtk;

class FontChooserWidgetExample {

    // Create the application itself
    constructor() {
        this.application = new Gtk.Application({ application_id: 'org.example.fontchooserwidget' });

        // Connect 'activate' and 'startup' signals to the callback functions
        this.application.connect('activate', this._onActivate.bind(this));
        this.application.connect('startup', this._onStartup.bind(this));
    }

    // Callback function for 'activate' signal presents windows when active
    _onActivate() {
        this.window.present();
    }

    // Callback function for 'startup' signal builds the UI
    _onStartup() {
        this._buildUI();
    }

    // Build the application's UI
    _buildUI() {
        // Create the application window
        this.window = new Gtk.ApplicationWindow  ({ application: this.application,
                                                    window_position: Gtk.WindowPosition.CENTER,
                                                    title: "FontChooserWidget",
                                                    default_width: 200,
                                                    default_height: 200,
                                                    border_width: 10 });

        this.fontChooser = new Gtk.FontChooserWidget();
        // a default font
        this.fontChooser.set_font("Sans");
        // a text to preview the font
        this.fontChooser.set_preview_text("This is an example of preview text!");

        // connect signal from the font chooser to the callback function
        this.fontChooser.connect("notify::font", this._fontCb.bind(this));

        // add the font chooser to the window
        this.window.add(this.fontChooser);
        this.window.show_all();
   }

     // callback function:
     _fontCb() {
        // print in the terminal
        print("You chose the font " + this.fontChooser.get_font());
    }
};

// Run the application
let app = new FontChooserWidgetExample();
app.application.run (ARGV);
